<?php

namespace Litecms\StairStep\Providers;

use Illuminate\Support\ServiceProvider;

class StairStepServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'stair_step');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'stair_step');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.stair_step', function ($app) {
            return $this->app->make('Litecms\StairStep\StairStep');
        });

                // Bind StairSteps to repository
        $this->app->bind(
            'Litecms\StairStep\Interfaces\StairStepsRepositoryInterface',
            \Litecms\StairStep\Repositories\Eloquent\StairStepsRepository::class
        );

        $this->app->register(\Litecms\StairStep\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\StairStep\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\StairStep\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.stair_step'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/stair_step.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/stair_step')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/stair_step')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
